@@ -8,17 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_budgets._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "aws_budget_notifier",
-    "0.3.14",
+    "0.3.17",
     __name__[0:-6],
-    "aws_budget_notifier@0.3.14.jsii.tgz",
+    "aws_budget_notifier@0.3.17.jsii.tgz",
 )
 
 __all__ = [
